ResolveProblem

Enum ResolveProblem 

#[non_exhaustive]
pub enum ResolveProblem {
Show 15 variants ResolveFailed { spec: String, base_dir: String, err: Error, }, TargetNotRegularFile { target: String, }, TargetIsRootFile { spec: String, }, ParentIdNotAbsoluteCanonical { parent_id: String, }, ParentResolveFailed { parent_id: String, from_name: String, err: Error, }, ParentNotRegularFile { parent: String, }, ParentHasNoDirectory { parent: String, }, ResolvesOutsideRoot { spec: String, root: String, }, TraversesSymlink { spec: String, }, AbsolutePathNotAllowed { spec: String, }, EmptyPath, InvalidExtension { spec: String, }, HiddenFile { spec: String, }, EmptyFragment, FragmentContainsHash { spec: String, },
}
Specific problems encountered during file include resolution.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ResolveFailed

Failed to canonicalize the include target path.

Fields

spec: String
base_dir: String
err: Error


TargetNotRegularFile

The include target is not a regular file.

Fields

target: String


TargetIsRootFile

The include target resolves to the configured root file itself (cyclic include).

Fields

spec: String


ParentIdNotAbsoluteCanonical

The parent include id was not an absolute canonical path.

Fields

parent_id: String


ParentResolveFailed

Failed to resolve the parent include source.

Fields

parent_id: String
from_name: String
err: Error


ParentNotRegularFile

The parent include is not a regular file.

Fields

parent: String


ParentHasNoDirectory

The parent include does not have a parent directory.

Fields

parent: String


ResolvesOutsideRoot

The include resolves outside the configured root directory.

Fields

spec: String
root: String

The include traverses a symlink, which is disabled by policy.

Fields

spec: String


AbsolutePathNotAllowed

Absolute include paths are not allowed.

Fields

spec: String


EmptyPath

The include path is empty.



InvalidExtension

The include target does not have a valid YAML extension (.yml or .yaml).

Fields

spec: String


HiddenFile

The include target is a hidden file (starts with a dot).

Fields

spec: String


EmptyFragment

The include fragment is empty.



FragmentContainsHash

The include fragment contains a ‘#’ character.

Fields

spec: String