#[repr(transparent)]pub struct ArcRecursion<T>(pub Weak<Mutex<Option<T>>>);Expand description
Thread-safe recursive reference to a parent ArcRecursive anchor.
It is more complex to use than RcRecursive because you must lock it before accessing the value.
See ArcRecursive for code example.
Tuple Fields
0: Weak<Mutex<Option<T>>>Implementations
Sourceimpl<T> ArcRecursion<T>
impl<T> ArcRecursion<T>
Sourcepub fn upgrade(&self) -> Option<ArcRecursive<T>>
pub fn upgrade(&self) -> Option<ArcRecursive<T>>
Try to upgrade the weak reference to ArcRecursive<T>.
Sourcepub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>
pub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>
Access the recursive value in one step, if it is still alive.
Sourcepub fn is_dangling(&self) -> bool
pub fn is_dangling(&self) -> bool
Returns true if the underlying value has been dropped (no strong refs remain).