ArcRecursive

Struct ArcRecursive 

#[repr(transparent)]
pub struct ArcRecursive<T>(pub Arc<Mutex<Option<T>>>);
The parent (origin) anchor definition that may have recursive references to it. This type provides the value for the references and must be placed where the original value is defined. Fields that reference this value (possibly recursively) must be wrapped in ArcRecursion.

use serde::Deserialize;
use serde_saphyr::{ArcRecursion, ArcRecursive};

#[derive(Deserialize)]
struct King {
    name: String,
    coronator: ArcRecursion<King>, // who crowned this king
}

#[derive(Deserialize)]
struct Kingdom {
    king: ArcRecursive<King>,
}

    let yaml = r#"
king: &root
  name: "Aurelian I"
  coronator: *root # this king crowned himself
"#;

    let kingdom_data: Kingdom = serde_saphyr::from_str(yaml).unwrap();
    let coronator = {
        let king_guard = kingdom_data.king.lock().unwrap();
        let king = king_guard.as_ref().expect("king should be initialized");
        king.coronator
            .upgrade()
            .expect("coronator should be alive")
    };

    let coronator_guard = coronator.lock().unwrap();
    let coronator_ref = coronator_guard
        .as_ref()
        .expect("coronator should be initialized");
    assert_eq!(coronator_ref.name, "Aurelian I");

Tuple Fields

0: Arc<Mutex<Option<T>>>

Implementations

Source

impl<T> ArcRecursive<T>

pub fn wrapping(x: T) -> Self

Create a new recursive anchor with an initialized value.

pub fn lock(&self) -> LockResult<MutexGuard<'_, Option<T>>>

Lock the recursive anchor value so that it can be accessed safely.