pub struct DefaultMessageFormatter;Expand description
Default developer-oriented message formatter.
This formatter at places produces recommendations on how to adjust settings and API calls for the parsing to work, so normally should not be user-facing. Use UserMessageFormatter for user-facing content, or implement custom MessageFormatter for full control over output.
Implementations
Sourceimpl DefaultMessageFormatter
impl DefaultMessageFormatter
Sourcepub fn with_localizer<'a>(
&self,
localizer: &'a dyn Localizer,
) -> DefaultMessageFormatterWithLocalizer<'a>
pub fn with_localizer<'a>( &self, localizer: &'a dyn Localizer, ) -> DefaultMessageFormatterWithLocalizer<'a>
Return a formatter that uses a custom Localizer.
This allows reusing the built-in developer-oriented messages while customizing
wording that is produced outside format_message (location suffixes, validation
issue composition, snippet labels, etc.).