ExternalMessage

Struct ExternalMessage 

pub struct ExternalMessage<'a> {
    pub source: ExternalMessageSource,
    pub original: &'a str,
    pub code: Option<&'a str>,
    pub params: &'a [(String, String)],
}
A best-effort description of an external message.

The crate should pass as much stable metadata as it has (e.g. code and params for validator) so the localizer can override specific messages without string matching.

Fields

source: ExternalMessageSourceoriginal: &'a str

The original text as provided by the external library.

code: Option<&'a str>

Stable-ish identifier when available (e.g. validator error code).

params: &'a [(String, String)]

Optional structured parameters when available.