RcRecursion

Struct RcRecursion 

#[repr(transparent)]
pub struct RcRecursion<T>(pub Weak<RefCell<Option<T>>>);
The possibly recursive reference to the parent anchor that must be RcRecursive. See RcRecursive for code example.

Tuple Fields

0: Weak<RefCell<Option<T>>>

Implementations

Source

impl<T> RcRecursion<T>

pub fn upgrade(&self) -> Option<RcRecursive<T>>

Try to upgrade the weak reference to RcRecursive<T>.

pub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>

Access the recursive value in one step, if it is still alive.

pub fn is_dangling(&self) -> bool

Returns true if the underlying value has been dropped (no strong refs remain).