#[repr(transparent)]pub struct RcRecursive<T>(pub Rc<RefCell<Option<T>>>);Expand description
The parent (origin) anchor definition that may have recursive references to it.
This type provides the value for the references and must be placed where the original value is defined.
Fields that reference this value (possibly recursively) must be wrapped in RcRecursion.
use std::cell::Ref;
use serde::Deserialize;
use serde_saphyr::{RcRecursion, RcRecursive};
#[derive(Deserialize)]
struct King {
name: String,
coronator: RcRecursion<King>, // who crowned this king
}
#[derive(Deserialize)]
struct Kingdom {
king: RcRecursive<King>,
}
let yaml = r#"
king: &root
name: "Aurelian I"
coronator: *root # this king crowned himself
"#;
let kingdom_data: Kingdom = serde_saphyr::from_str(yaml).unwrap();
let king: Ref<King> = kingdom_data.king.borrow();
let coronator = king
.coronator
.upgrade().expect("coronator always exists");
let coronator_name = &coronator.borrow().name;
assert_eq!(coronator_name, "Aurelian I");Tuple Fields
0: Rc<RefCell<Option<T>>>Implementations
Sourceimpl<T> RcRecursive<T>
impl<T> RcRecursive<T>
Sourcepub fn try_borrow_initialized(&self) -> Option<Ref<'_, T>>
pub fn try_borrow_initialized(&self) -> Option<Ref<'_, T>>
Try to borrow the inner value if the recursive placeholder has been initialized.
Returns None while a recursive anchor is still being deserialized.
Sourcepub fn borrow(&self) -> Ref<'_, T>
pub fn borrow(&self) -> Ref<'_, T>
Borrow the inner value.
Panics
Panics if called while a recursive anchor placeholder is still uninitialized.
Use try_borrow_initialized when early access is possible.