RenderOptions

Struct RenderOptions 

#[non_exhaustive]
pub struct RenderOptions<'a> { pub formatter: &'a dyn MessageFormatter, pub snippets: SnippetMode, }
Options for deferred error rendering.

Prefer constructing this via the render_options! macro instead of a struct literal. This keeps call sites stable even if new fields are added in the future (this type is #[non_exhaustive]).

Example (using the render_options! macro)

use serde_saphyr::{DefaultMessageFormatter, SnippetMode};

let dev = DefaultMessageFormatter;
// Customize how an error is rendered later (formatter + snippet mode).
let render_opts = serde_saphyr::render_options! {
    formatter: &dev,
    snippets: SnippetMode::Off,
};

let err = serde_saphyr::from_str::<String>("").unwrap_err();
let rendered = err.render_with_options(render_opts);
assert!(rendered.contains("unexpected"));

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
formatter: &'a dyn MessageFormatter

Message formatter used to produce the core error message text.

snippets: SnippetMode

Snippet rendering mode.

Implementations

Source

impl<'a> RenderOptions<'a>

pub fn new(formatter: &'a dyn MessageFormatter) -> Self

Construct render options with the given message formatter and default values for all other fields.

Defaults: