UserMessageFormatter

Struct UserMessageFormatter 

pub struct UserMessageFormatter;
User-facing message formatter.

This formatter simplifies technical errors and removes internal details.

use serde_saphyr::UserMessageFormatter;

let err = serde_saphyr::from_str::<String>("").unwrap_err();
let msg = err.render_with_formatter(&UserMessageFormatter);

assert_eq!(msg, "unexpected end of file at line 1, column 1");

Implementations

Source

impl UserMessageFormatter

pub fn with_localizer<'a>( &self, localizer: &'a dyn Localizer, ) -> UserMessageFormatterWithLocalizer<'a>

Return a formatter that uses a custom Localizer.

This allows reusing the built-in user-facing messages while customizing wording that is produced outside format_message (location suffixes, validation issue composition, snippet labels, etc.).