ArcRecursion

Struct ArcRecursion 

#[repr(transparent)]
pub struct ArcRecursion<T>(pub Weak<Mutex<Option<T>>>);
The possibly recursive reference to the parent anchor that must be ArcRecursive, thread safe It is more complex to use than RcRecursive (you need to lock it before accessing the value) See ArcRecursive for code example.

Tuple Fields

0: Weak<Mutex<Option<T>>>

Implementations

Source

impl<T> ArcRecursion<T>

pub fn upgrade(&self) -> Option<ArcRecursive<T>>

Try to upgrade the weak reference to ArcRecursive<T>.

pub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>

Access the recursive value in one step, if it is still alive.

pub fn is_dangling(&self) -> bool

Returns true if the underlying value has been dropped (no strong refs remain).