#[repr(transparent)]pub struct RcRecursion<T>(pub Weak<RefCell<Option<T>>>);Expand description
The possibly recursive reference to the parent anchor that must be RcRecursive.
See RcRecursive for code example.
Tuple Fields
0: Weak<RefCell<Option<T>>>Implementations
Sourceimpl<T> RcRecursion<T>
impl<T> RcRecursion<T>
Sourcepub fn upgrade(&self) -> Option<RcRecursive<T>>
pub fn upgrade(&self) -> Option<RcRecursive<T>>
Try to upgrade the weak reference to RcRecursive<T>.
Sourcepub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>
pub fn with<R>(&self, f: impl FnOnce(&T) -> R) -> Option<R>
Access the recursive value in one step, if it is still alive.
Sourcepub fn is_dangling(&self) -> bool
pub fn is_dangling(&self) -> bool
Returns true if the underlying value has been dropped (no strong refs remain).