RcRecursive

Struct RcRecursive 

#[repr(transparent)]
pub struct RcRecursive<T>(pub Rc<RefCell<Option<T>>>);
The parent (origin) anchor definition that may have recursive references to it. This type provides the value for the references and must be placed where the original value is defined. Fields that reference this value (possibly recursively) must be wrapped in RcRecursion.

use std::cell::Ref;
use serde::Deserialize;
use serde_saphyr::{RcRecursion, RcRecursive};
#[derive(Deserialize)]
struct King {
    name: String,
    coronator: RcRecursion<King>, // who crowned this king
}

#[derive(Deserialize)]
struct Kingdom {
    king: RcRecursive<King>,
}
    let yaml = r#"
king: &root
  name: "Aurelian I"
  coronator: *root # this king crowned himself
"#;

let kingdom_data: Kingdom = serde_saphyr::from_str(yaml).unwrap();
    let king: Ref<King> = kingdom_data.king.borrow();
    let coronator = king
        .coronator
        .upgrade().expect("coronator always exists");
    let coronator_name = &coronator.borrow().name;
    assert_eq!(coronator_name, "Aurelian I");

Tuple Fields

0: Rc<RefCell<Option<T>>>

Implementations

Source

impl<T> RcRecursive<T>

pub fn wrapping(x: T) -> Self

Create a new recursive anchor with an initialized value.

pub fn borrow(&self) -> Ref<'_, T>

Borrow the inner value